pub enum ConfigError {
ConfigBuildError(ConfigError),
FileReadError(String, Error),
UnknownFormat(String),
YamlError(Error),
JsonError(Error),
TomlError(Error),
ValidationErrors(ValidationErrors),
}Expand description
Represents errors that occur during configuration parsing, loading, and validation.
Variants
ConfigBuildError(ConfigError)
Error originating from the config crate when building configuration.
FileReadError(String, Error)
Error indicating a failure to read a configuration file from the filesystem.
UnknownFormat(String)
Error for unsupported or unknown file extensions during configuration loading.
YamlError(Error)
Error encountered during YAML deserialization.
JsonError(Error)
Error encountered during JSON deserialization.
TomlError(Error)
Error encountered during TOML deserialization.
ValidationErrors(ValidationErrors)
Error due to validation failures of configuration entities.